@@ -40,6 +40,8 @@ static GSList *day_events[NUM_HOURS], *untimed_events;
 static GtkWidget *rem_area;
 static GtkWidget *datesel, *calendar, *scrolled_window;
 
+static GdkGC *gray_gc;
+
 /* Day renderer */
 static event_t sel_event;
 static day_page_t page_app, page_rem;
@@ -76,16 +78,12 @@ day_page_new (GtkWidget * widget)
 static void
 day_page_draw_empty (const day_page_t page)
 {
-  GdkGC *white_gc, *black_gc;
+  GdkGC *white_gc;
 
   white_gc = page->widget->style->white_gc;
-  black_gc = page->widget->style->black_gc;
 
   gdk_draw_rectangle (page->widget->window, white_gc,
 		      TRUE, 0, 0, page->width, page->height);
-  gdk_draw_rectangle (page->widget->window, black_gc,
-		      FALSE, 0, 0, page->width - 1, page->height - 1);
-
 }
 
 static void
@@ -124,7 +122,7 @@ day_page_calc_time_width (day_page_t page)
 static void
 day_page_draw_background (const day_page_t page)
 {
-  GdkGC *gray_gc, *white_gc, *black_gc;
+  GdkGC *white_gc, *black_gc;
   GtkWidget *widget;
   guint i;
   PangoLayout *pl;
@@ -133,9 +131,11 @@ day_page_draw_background (const day_page_t page)
   widget = page->widget;
   pl = gtk_widget_create_pango_layout (widget, NULL);
   white_gc = widget->style->white_gc;
-  gray_gc = pen_new (widget, 58905, 58905, 56610);
   black_gc = widget->style->black_gc;
 
+  if (! gray_gc)
+    gray_gc = pen_new (draw, 58905, 58905, 56610);
+
   /* Row height */
   /* Draw the hour column */
   gdk_draw_rectangle (widget->window, white_gc, TRUE, 0, 0, page->width,
@@ -175,7 +175,6 @@ day_page_draw_background (const day_page_t page)
 		 page->time_width, page->height - 1);
 
   g_object_unref (pl);
-  g_object_unref (gray_gc);
 }
 
 gboolean
@@ -322,10 +321,9 @@ delete_event (event_t ev, GtkWidget * d)
 static void
 day_view_expose (void)
 {
-  GdkGC *white_gc, *gray_gc, *black_gc;
+  GdkGC *white_gc, *black_gc;
   gint width = 0, height = 0;
   white_gc = draw->style->white_gc;
-  gray_gc = pen_new (draw, 58905, 58905, 56610);
   black_gc = draw->style->black_gc;
 
   gdk_window_get_size (draw->window, &width, &height);
@@ -345,8 +343,6 @@ day_view_expose (void)
 
   day_render_set_event_rectangles (dr);
   draw_appointments (dr);
-
-  g_object_unref (gray_gc);
 }
 
 static gboolean
@@ -360,13 +356,12 @@ day_view_expose_cb (GtkWidget * widget,
 static int
 reminder_view_init ()
 {
-  GdkGC *white_gc, *black_gc, *cream_gc;
+  GdkGC *black_gc, *cream_gc;
 
   time_t end, start;
   struct tm tm_start, tm_end;
   GSList *events, *iter, *rem_list = NULL;
 
-
   localtime_r (&viewtime, &tm_start);
 
   tm_start.tm_hour = 0;
@@ -391,15 +386,25 @@ reminder_view_init ()
         }
     }
 
-  white_gc = rem_area->style->white_gc;
-  black_gc = rem_area->style->black_gc;
-
   if (rem_render)
-    day_render_delete (rem_render);
+    {
+      day_render_delete (rem_render);
+      rem_render = NULL;
+    }
 
+  if (rem_list == NULL)
+    {
+      gtk_widget_hide (rem_area);
+      return TRUE;
+    }
+
+  black_gc = rem_area->style->black_gc;
   cream_gc = pen_new (rem_area, 65535, 64005, 51100);
   rem_render = day_render_new (rem_area, page_rem, cream_gc, black_gc,
 			       viewtime, 5, 0, 1, rem_list);
+  g_object_unref (cream_gc);
+
+  gtk_widget_show (rem_area);
 
   return TRUE;
 }
@@ -407,11 +412,10 @@ reminder_view_init ()
 static void
 reminder_view_expose ()
 {
-  gint len;
   gint width = 0, height = 0;
 
   if (rem_render == NULL)
-    reminder_view_init ();
+    return;
   
   gdk_window_get_size (rem_area->window, &width, &height);
     
@@ -422,16 +426,8 @@ reminder_view_expose ()
   rem_render->offset.x = 0;
   day_render_set_event_rectangles (rem_render);
 
-  len = g_slist_length (rem_render->events);
-  if (len)
-    {
-      gtk_widget_set_size_request (rem_area, -1, dr->page->height / 20);
-      draw_appointments (rem_render);
-    }
-  else
-    {
-      gtk_widget_set_size_request (rem_area, -1, 0);
-    }
+  gtk_widget_set_size_request (rem_area, -1, dr->page->height / 20);
+  draw_appointments (rem_render);
 }
 
 static gboolean
@@ -445,13 +441,10 @@ reminder_view_expose_cb (GtkWidget * widget,
 int
 day_view_init (void)
 {
-  GdkGC *white_gc, *post_him_yellow, *black_gc;
-
   time_t end, start;
   struct tm tm_start, tm_end;
   GSList *events, *iter, *ev_list = NULL;
 
-
   localtime_r (&viewtime, &tm_start);
 
   tm_start.tm_hour = 0;
@@ -473,9 +466,6 @@ day_view_init (void)
         ev_list = g_slist_append (ev_list, ev);
     }
 
-  white_gc = draw->style->white_gc;
-  black_gc = draw->style->black_gc;
-
   if (dr)
     {
       g_slist_free (dr->events);
@@ -485,10 +475,14 @@ day_view_init (void)
   else
     {
       /* Don't want to infinge some patents here */
+      GdkGC *black_gc, *post_him_yellow;
+      black_gc = rem_area->style->black_gc;
       post_him_yellow = pen_new (draw, 63222, 59110, 33667);
       dr = day_render_new (draw, page_app, post_him_yellow, black_gc, viewtime,
                            5, 4, NUM_HOURS, ev_list);
+      g_object_unref (post_him_yellow);
     }
+
   return TRUE;
 }
 
@@ -503,7 +497,8 @@ void
 reminder_view_update ()
 {
   reminder_view_init ();
-  reminder_view_expose ();
+  if (rem_render)
+    reminder_view_expose ();
 }
 
 static void
@@ -516,7 +511,6 @@ day_changed_calendar (GtkWidget * widget)
 
   gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
 
-
   if (tm.tm_year != (year - 1900) || tm.tm_mon != month || tm.tm_mday != day)
     {
       tm.tm_year = year - 1900;
@@ -560,7 +554,6 @@ scroll_to (GtkWidget * scrolled, gint hour)
   if (value > (adj->upper - adj->page_size))
     value = adj->upper - adj->page_size;
 
-  gtk_adjustment_clamp_page (adj, lower, upper);
   gtk_adjustment_set_value (adj, value);
 }
 
@@ -680,8 +673,8 @@ day_view (void)
   delete_event_button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
   save_button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
 #endif
-  send_ir_button = gtk_button_new_with_label (_("Send via infared"));
-  send_bt_button = gtk_button_new_with_label (_("Send via bluetooth"));
+  send_ir_button = gtk_button_new_with_label (_("Send via infra-red"));
+  send_bt_button = gtk_button_new_with_label (_("Send via Bluetooth"));
 
   gtk_button_set_relief (GTK_BUTTON (edit_event_button), GTK_RELIEF_NONE);
   gtk_button_set_relief (GTK_BUTTON (delete_event_button), GTK_RELIEF_NONE);
@@ -727,7 +720,7 @@ day_view (void)
   g_signal_connect (G_OBJECT (send_ir_button), "clicked",
 		    G_CALLBACK (send_ir_cb), NULL);
 
-  g_signal_connect (G_OBJECT (send_ir_button), "clicked",
+  g_signal_connect (G_OBJECT (send_bt_button), "clicked",
 		    G_CALLBACK (send_bt_cb), NULL);
 
   gtk_window_set_decorated (GTK_WINDOW (popup), TRUE);
@@ -771,7 +764,6 @@ day_view (void)
   g_signal_connect (G_OBJECT (calendar),
 		    "day-selected", G_CALLBACK (day_changed_calendar), NULL);
 
-
   gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW
 					 (scrolled_window), draw);
   gtk_viewport_set_shadow_type (GTK_VIEWPORT (draw->parent), GTK_SHADOW_NONE);
