@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 Philip Blundell <philb@gnu.org>
+ * Copyright (C) 2002, 2005 Philip Blundell <philb@gnu.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -12,17 +12,16 @@
 
 extern GtkWidget *day_view (void);
 extern gboolean day_view_combined_times;
-extern void day_free_lists(void);
-int day_view_init ();
-
-
+extern void day_free_lists (void);
+extern int day_view_init ();
+extern gboolean day_view_button_press (GtkWidget * widget, GdkEventButton * event, gpointer d);
 
 typedef struct day_page {
-	GtkWidget *widget;
-	guint width;
-	guint height;
-	guint height_min;
-	guint time_col_ratio;
+  GtkWidget *widget;
+  guint width;
+  guint height;
+  guint height_min;
+  guint time_width;
 } *day_page_t ;
 
 
